[PATCH] D153277: [BOLT][RISCV] Recognize mapping symbols

Job Noorman via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Sat Jul 29 00:19:30 PDT 2023


This revision was automatically updated to reflect the committed changes.
jobnoorman marked an inline comment as done.
Closed by commit rGfc395884decf: [BOLT][RISCV] Recognize mapping symbols (authored by jobnoorman).

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D153277/new/

https://reviews.llvm.org/D153277

Files:
  bolt/lib/Core/BinaryContext.cpp
  bolt/lib/Rewrite/RewriteInstance.cpp
  bolt/test/RISCV/mapping-syms.s


Index: bolt/test/RISCV/mapping-syms.s
===================================================================
--- /dev/null
+++ bolt/test/RISCV/mapping-syms.s
@@ -0,0 +1,27 @@
+/// FIXME llvm-mc is used instead of clang because we need a recent change in
+/// the RISC-V MC layer (D153260). Once that one is released, we can switch to
+/// clang. (Note that the pre-merge check buildbots use the system's clang).
+// RUN: llvm-mc -triple riscv64 -mattr=+c -filetype obj -o %t.o %s
+// RUN: ld.lld -o %t %t.o
+// RUN: llvm-bolt --print-cfg --print-only=_start -o %t.bolt %t 2>&1 | FileCheck %s
+// RUN: llvm-objdump -d %t.bolt | FileCheck --check-prefix=CHECK-OBJDUMP %s
+
+// CHECK-NOT: BOLT-WARNING
+
+/// Check that .word is not disassembled by BOLT
+// CHECK: 00000000: nop
+// CHECK: 00000002: ret
+
+/// Check .word is still present in output
+// CHECK-OBJDUMP: <_start>:
+// CHECK-OBJDUMP-NEXT: nop
+// CHECK-OBJDUMP-NEXT: unimp
+// CHECK-OBJDUMP-NEXT: unimp
+// CHECK-OBJDUMP-NEXT: ret
+    .text
+    .globl _start
+    .p2align 1
+_start:
+    nop
+    .word 0x0
+    ret
Index: bolt/lib/Rewrite/RewriteInstance.cpp
===================================================================
--- bolt/lib/Rewrite/RewriteInstance.cpp
+++ bolt/lib/Rewrite/RewriteInstance.cpp
@@ -881,7 +881,7 @@
         }
       };
 
-  if (BC->isAArch64()) {
+  if (BC->isAArch64() || BC->isRISCV()) {
     addExtraDataMarkerPerSymbol(SortedFileSymbols, SortedMarkerSymbols);
     LastSymbol = std::stable_partition(
         SortedFileSymbols.begin(), SortedFileSymbols.end(),
Index: bolt/lib/Core/BinaryContext.cpp
===================================================================
--- bolt/lib/Core/BinaryContext.cpp
+++ bolt/lib/Core/BinaryContext.cpp
@@ -1760,10 +1760,10 @@
 }
 
 MarkerSymType BinaryContext::getMarkerType(const SymbolRef &Symbol) const {
-  // For aarch64, the ABI defines mapping symbols so we identify data in the
-  // code section (see IHI0056B). $x identifies a symbol starting code or the
-  // end of a data chunk inside code, $d indentifies start of data.
-  if (!isAArch64() || ELFSymbolRef(Symbol).getSize())
+  // For aarch64 and riscv, the ABI defines mapping symbols so we identify data
+  // in the code section (see IHI0056B). $x identifies a symbol starting code or
+  // the end of a data chunk inside code, $d indentifies start of data.
+  if ((!isAArch64() && !isRISCV()) || ELFSymbolRef(Symbol).getSize())
     return MarkerSymType::NONE;
 
   Expected<StringRef> NameOrError = Symbol.getName();


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D153277.545342.patch
Type: text/x-patch
Size: 2522 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20230729/70efeb23/attachment.bin>


More information about the llvm-commits mailing list